import { BaseArchive } from "./StreamArchive";
import { AdImpression, AdEngagement, AdMobileConversion, AdOnlineConversion } from "./types/GDPRAds";
/**
 * Twitter collected data about ads viewed and interacted with by the archive owner.
 */
export declare class AdArchive {
    /**
     * Collected data about ads viewed by archive owner.
     */
    impressions: AdImpression[];
    /**
     * Collected data about ads archive owner have interacted with.
     */
    engagements: AdEngagement[];
    /**
     * Mobile application events associated with archive owner account in the last 90 days
     * which are attributable to a Promoted Tweet engagement on Twitter.
     *
     * Ads which archive owner might have seen **on mobile app** and "converted" to real action:
     *
     * For example: Installed an application, used an app targeted by a ad...
     */
    mobile_conversions: AdMobileConversion[];
    /**
     * All online (website) activities associated with archive owner account in the last 90 days via advertiser
     * website integrations which are attributable to a Promoted Tweet engagement on Twitter.
     *
     * Ads which archive owner might have seen **on desktop website** and "converted" to real action:
     *
     * For example: Clicked on the ad and see a webpage...
     */
    online_conversions: AdOnlineConversion[];
    __init(archive: BaseArchive<any>): Promise<void>;
    /**
     * Impressions by display location (where archive owner seen it on Twitter environnement: Timeline, profile...)
     */
    get impressions_by_location(): {
        [location: string]: AdImpression[];
    };
    /**
     * Impressions by advertiser screen name (with @ in it).
     *
     * Real advertiser name can be obtains with `impression.advertiserInfo.advertiserName`.
     */
    get impressions_by_advertiser(): {
        [advertiser: string]: AdImpression[];
    };
    /**
     * All impressions linked to an engagement, sorted by engagement types.
     *
     * A single impression can have multiple engagement types.
     */
    get impressions_by_engagement_type(): {
        [engagementType: string]: AdImpression[];
    };
}
export default AdArchive;
