import TwitterArchive from "./index";
import { UserLoadObject } from "./UserData";
import { ScreenNameChange, GPDRScreenNameHistory } from "./types/GDPRUserInformations";
import { ArchiveSyntheticInfo } from "./types/Internal";
import { PartialFavorite } from "./types/GDPRExtended";
import { GDPRMoment } from "./types/GDPRMoments";
export interface ArchiveSave {
    tweets: ArrayBuffer;
    dms: ArrayBuffer;
    info: ArchiveSyntheticInfo;
    mutes: string[];
    blocks: string[];
    /** 1.0.0: `GPDRScreenNameHistory[]` ; 1.1.0+: `ScreenNameChange[]` */
    screen_name_history: ScreenNameChange[] | GPDRScreenNameHistory[];
    /** 1.1.0+ */
    favorites?: PartialFavorite[];
    /** 1.1.0+ */
    user?: UserLoadObject;
    followers?: string[];
    followings?: string[];
    moments?: GDPRMoment[];
    lists?: {
        created: string[];
        member_of: string[];
        subscribed: string[];
    };
    ad_archive?: ArrayBuffer;
}
export interface ArchiveSaveOptions {
    tweets?: boolean;
    dms?: boolean;
    mutes?: boolean;
    favorites?: boolean;
    blocks?: boolean;
    followers?: boolean;
    followings?: boolean;
    moments?: boolean;
    lists?: boolean;
    ad_archive?: boolean;
    /** Summary user data and screen name history is always stored. */
    user?: {
        phone_number?: boolean;
        verified?: boolean;
        personalization?: boolean;
        protected_history?: boolean;
        age_info?: boolean;
        email_address_changes?: boolean;
        login_ips?: boolean;
        timezone?: boolean;
        applications?: boolean;
    };
}
export declare class ArchiveSaver {
    static readonly SUPPORTED_SAVE_VERSIONS: string[];
    static readonly CURRENT_EXPORT_VERSION = "1.1.0";
    /**
     * Create a save from a Twitter Archive.
     *
     * Restore an `ArchiveSave` with `.restore()`.
     *
     * Default parameter for {options} is:
     * ```ts
     * options = {
     *  tweets: true,
     *  dms: true,
     *  mutes: true,
     *  favorites: true,
     *  blocks: true,
     *  user: {}
     * }
     * ```
     */
    static create(archive: TwitterArchive, options?: ArchiveSaveOptions): Promise<ArchiveSave>;
    /**
     * Create a Twitter Archive from an `ArchiveSave`.
     */
    static restore(save: ArchiveSave | Promise<ArchiveSave>): Promise<TwitterArchive>;
}
export default ArchiveSaver;
