import { PartialFavorite, GDPRFavorites } from "./types/GDPRExtended";
export declare class FavoriteArchive {
    protected index: {
        [tweetId: string]: PartialFavorite;
    };
    protected fav_set: Set<string>;
    add(favs: GDPRFavorites | PartialFavorite[]): void;
    /**
     * Check if {tweet_id} has been favorited.
     */
    has(tweet_id: string): boolean;
    /**
     * Get favorites informations of {tweet_id}.
     *
     * If {tweet_id} is not favorited, returns `undefined`.
     */
    get(tweet_id: string): PartialFavorite;
    [Symbol.iterator](): Generator<PartialFavorite, void, undefined>;
    /**
     * Get all the registred favorites
     */
    get all(): PartialFavorite[];
    /**
     * Get all favorited tweets in the archive, inside a Set for quick check (like old `archive.extended_gdpr.favorites`).
     */
    get registred(): Set<string>;
    /**
     * Number of favorites.
     */
    get length(): number;
    /** `true` if this archive's favorites supported "extended" properties: `.fullText` and `.expandedUrl`. */
    get has_extended_favorites(): boolean;
}
