"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class FavoriteArchive {
    constructor() {
        this.index = {};
    }
    add(favs) {
        for (const f of favs) {
            if ('like' in f) {
                this.index[f.like.tweetId] = f.like;
            }
            else {
                this.index[f.tweetId] = f;
            }
        }
    }
    /**
     * Check if {tweet_id} has been favorited.
     */
    has(tweet_id) {
        return tweet_id in this.index;
    }
    /**
     * Get favorites informations of {tweet_id}.
     *
     * If {tweet_id} is not favorited, returns `undefined`.
     */
    get(tweet_id) {
        return this.index[tweet_id];
    }
    *[Symbol.iterator]() {
        yield* this.all;
    }
    /**
     * Get all the registred favorites
     */
    get all() {
        return Object.values(this.index);
    }
    /**
     * Get all favorited tweets in the archive, inside a Set for quick check (like old `archive.extended_gdpr.favorites`).
     */
    get registred() {
        if (this.fav_set) {
            return this.fav_set;
        }
        return this.fav_set = new Set(Object.keys(this.index));
    }
    /**
     * Number of favorites.
     */
    get length() {
        return this.all.length;
    }
    /** `true` if this archive's favorites supported "extended" properties: `.fullText` and `.expandedUrl`. */
    get has_extended_favorites() {
        if (this.length) {
            return 'fullText' in this.all[0];
        }
        return false;
    }
}
exports.FavoriteArchive = FavoriteArchive;
