import JSZip from 'jszip';
import { ZipEntry } from './StreamZip';
/**
 * string: Filename. WILL USE STREAMING METHOD.
 *
 * number[] | Uint8Array | ArrayBuffer: Array of bytes
 *
 * Blob: File for browser. WILL USE STREAMING METHOD.
 *
 * JSZip | Archive: Existing archives
 */
export declare type AcceptedZipSources = string | number[] | Uint8Array | ArrayBuffer | Blob | JSZip | Archive;
export declare type ConstructibleArchives = BaseArchive<ZipEntry> | BaseArchive<JSZip.JSZipObject>;
export interface BaseArchive<T> {
    ready: () => Promise<void>;
    dir: (name: string) => BaseArchive<T>;
    has: (name: string) => boolean;
    search: (query: RegExp) => T[];
    searchDir: (query: RegExp) => T[];
    get: (name: string, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean) => Promise<any>;
    read: (file: T, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean) => Promise<any>;
    ls: (current_dir_only?: boolean) => {
        [name: string]: T;
    };
    fromFile: (name: string | T) => Promise<Archive>;
}
export declare function constructArchive(archive: AcceptedZipSources): ConstructibleArchives;
export declare class Archive implements BaseArchive<JSZip.JSZipObject> {
    protected _ready: Promise<void>;
    protected archive: JSZip;
    constructor(file: AcceptedZipSources);
    ready(): Promise<void>;
    dir(name: string): Archive;
    has(name: string): boolean;
    get(name: string, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean): Promise<any>;
    search(query: RegExp): JSZip.JSZipObject[];
    searchDir(query: RegExp): JSZip.JSZipObject[];
    read(file: JSZip.JSZipObject, type?: "text" | "arraybuffer" | "blob", parse_auto?: boolean): Promise<any>;
    ls(current_dir_only?: boolean): {
        [name: string]: JSZip.JSZipObject;
    };
    /**
     * Create a new instance of Archive from a file contained in this archive.
     *
     * @param name File name or file object
     */
    fromFile(name: string | JSZip.JSZipObject): Promise<Archive>;
    get raw(): JSZip;
}
export default Archive;
