/// <reference types="node" />
import events from 'events';
import stream from 'stream';
export declare type AcceptedFile = File | string;
export interface FileReader<T, S = T> {
    reader: (file: T, buffer: Buffer, offset_in_buffer: number, length: number, position_in_file: number) => Promise<number> | number;
    opener?: (file: T) => S | Promise<S>;
    getSize: (file: S, original: T) => Promise<number> | number;
    getName: (file: S, original: T) => Promise<string> | string;
}
export default class StreamZip<T, S = T> extends events.EventEmitter {
    protected fileReader?: FileReader<T, S>;
    chunkSize?: number;
    file: S;
    fileSize: number;
    ready: boolean;
    fileName: string;
    _entries: {
        [name: string]: ZipEntry;
    };
    centralDirectory: CentralDirectoryHeader;
    comment: string;
    entriesCount: number;
    op: {
        win?: FileWindowBuffer<S>;
        totalReadLength?: number;
        minPos?: number;
        pos?: number;
        lastPos?: number;
        chunkSize?: number;
        firstByte?: number;
        entriesLeft?: number;
        sig?: number;
        complete?: Function;
        lastBufferPosition?: number;
        lastBytesRead?: number;
        entry?: ZipEntry;
        move?: boolean;
    };
    config: {
        entries: boolean;
        skipEntryNameValidation: boolean;
    };
    constructor(file: T, fileReader?: FileReader<T, S>, storeEntries?: boolean, chunkSize?: number, skip_valid?: boolean);
    protected open(chunkSize?: number): void;
    protected readCentralDirectory(): void;
    protected readUntilFoundCallback(err: any, bytesRead: number): boolean;
    readCentralDirectoryComplete: () => Promise<boolean>;
    protected readEntries(): Promise<boolean>;
    protected readEntriesCallback(bytesRead: number): boolean;
    protected checkEntriesExist(): void;
    entry(name: string): ZipEntry;
    get entries(): {
        [name: string]: ZipEntry;
    };
    readZip64CentralDirectoryLocator(): Promise<boolean>;
    readZip64CentralDirectoryLocatorComplete: () => Promise<boolean>;
    readZip64CentralDirectoryComplete: () => void;
    dataOffset(entry: ZipEntry): number;
    canVerifyCrc(entry: ZipEntry): boolean;
    stream(entry: ZipEntry): Promise<EntryDataReaderStream<S>>;
    openEntry(entry: ZipEntry | string): Promise<[any, ZipEntry]>;
    close(): void;
    entryData(entry: ZipEntry | string): Promise<Buffer>;
}
declare class CentralDirectoryHeader {
    volumeEntries: number;
    totalEntries: number;
    size: number;
    offset: number;
    commentLength: number;
    headerOffset: number;
    read(data: Buffer): void;
}
export declare class ZipEntry {
    verMade: number;
    version: number;
    flags: number;
    method: number;
    time: number;
    crc: number;
    compressedSize: number;
    size: number;
    fnameLen: number;
    extraLen: number;
    comLen: number;
    diskStart: number;
    inattr: number;
    attr: number;
    offset: number;
    name: string;
    isDirectory: boolean;
    comment: string;
    headerOffset: number;
    readHeader(data: Buffer, offset: number): void;
    readDataHeader(data: Buffer): void;
    read(data: Buffer, offset: number): void;
    readExtra(data: Buffer, offset: number): void;
    validateName(): void;
    parseZip64Extra(data: Buffer, offset: number, length: number): void;
    get encrypted(): boolean;
    get isFile(): boolean;
}
declare class FsRead<S> {
    file: S;
    buffer: Buffer;
    offset: number;
    length: number;
    position: number;
    fileReader: FileReader<any, S>;
    bytesRead: number;
    waiting: boolean;
    constructor(file: S, buffer: Buffer, offset: number, length: number, position: number, fileReader: FileReader<any, S>);
    read(): Promise<number>;
    readCallback(bytesRead: number): Promise<number>;
}
declare class FileWindowBuffer<S> {
    file: S;
    fileReader: FileReader<any, S>;
    position: number;
    buffer: Buffer;
    fsOp: FsRead<S>;
    constructor(file: S, fileReader: FileReader<any, S>);
    checkOp(): void;
    read(pos: number, length: number): Promise<number>;
    expandLeft(length: number): Promise<number>;
    expandRight(length: number): Promise<number>;
    moveRight(_: number, shift: number): Promise<number>;
}
declare class EntryDataReaderStream<S> extends stream.Readable {
    file: S;
    offset: number;
    length: number;
    fileReader: FileReader<any, S>;
    pos: number;
    constructor(file: S, offset: number, length: number, fileReader: FileReader<any, S>);
    _read(n: number): void;
    readCallback(bytesRead: number, buffer: Buffer): void;
}
export {};
