"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TwitterDateHelper = new class TwitterDateHelper {
    /**
     * Parse a raw Twitter date, like from a `dm.createdAt`.
     *
     * For a tweet, please use `TweetArchive.dateFromTweet(tweet)` instead, it's optimized !
     *
     * For a `LinkedDirectMessage`, use property `.createdAtDate` !
     */
    parseAdDate(date) {
        return new Date(date.split(" ", 2).join("T") + ".000Z");
    }
    /**
     * Parse a raw Twitter date, from a `dm.createdAt` or `tweet.created_at`.
     *
     * For a tweet, please use `dateFromTweet(tweet)` instead, it's optimized !
     *
     * For dates in ad data (everthing that comes from `AdArchive`), use instead `AdArchive.parseAdDate()` !
     *
     * For a `LinkedDirectMessage`, use property `.createdAtDate` !
     */
    parseTwitterDate(date) {
        try {
            const d = new Date(date);
            if (isNaN(d.getTime())) {
                throw "";
            }
            else {
                return d;
            }
        }
        catch (e) {
            return new Date(date.replace(/\s(.+)\s.+/, 'T$1.000Z'));
        }
    }
    /** Return the `Date` object affiliated to **tweet**. */
    dateFromTweet(tweet) {
        if (tweet.created_at_d && tweet.created_at_d instanceof Date) {
            return tweet.created_at_d;
        }
        return tweet.created_at_d = this.parseTwitterDate(tweet.created_at);
    }
};
exports.default = exports.TwitterDateHelper;
